==> cdo_1.9.6~rc6.orig.tar.xz: cdo-1.9.6~rc6/src/lib/yac/grid_unstruct.h <==
/**
 * @file grid_unstruct.h
 * @brief Initialisation for 2-dimensional unstructured grids
 *
 * @copyright Copyright  (C)  2013 Moritz Hanke <hanke@dkrz.de>
 *                                 Rene Redler <rene.redler@mpimet.mpg.de>
 *
 * @version 1.0
 * @author Moritz Hanke <hanke@dkrz.de>
 *         Rene Redler <rene.redler@mpimet.mpg.de>
 */
/*
 * Keywords:
 * Maintainer: Moritz Hanke <hanke@dkrz.de>
 *             Rene Redler <rene.redler@mpimet.mpg.de>
 * URL: https://doc.redmine.dkrz.de/YAC/html/index.html
 *
 * This file is part of YAC.
 *
 * YAC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * YAC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with YAC.  If not, see <http://www.gnu.org/licenses/gpl.txt>.
 */

#ifndef GRID_UNSTRUCT_H
#define GRID_UNSTRUCT_H

#include "grid.h"

struct grid * yac_unstruct_grid_new(double * coordinates_x, double * coordinates_y,
                                    unsigned num_vertices, struct dep_list cell_to_vertex);

struct grid * yac_unpack_unstruct_grid(double * dble_buf, unsigned * dble_buf_data_size,
                                       unsigned * uint_buf, unsigned * uint_buf_data_size);

void yac_unstruct_grid_set_cell_to_vertex_by_user(
  struct grid * grid, unsigned cell_to_vertex_by_user);

#endif // GRID_UNSTRUCT_H

==> cdo_1.9.9~rc8.orig.tar.xz: cdo-1.9.9~rc8/src/lib/yac/grid_unstruct.h <==
/**
 * @file grid_unstruct.h
 * @brief Initialisation for 2-dimensional unstructured grids
 *
 * @copyright Copyright  (C)  2013 Moritz Hanke <hanke@dkrz.de>
 *                                 Rene Redler <rene.redler@mpimet.mpg.de>
 *
 * @version 1.0
 * @author Moritz Hanke <hanke@dkrz.de>
 *         Rene Redler <rene.redler@mpimet.mpg.de>
 */
/*
 * Keywords:
 * Maintainer: Moritz Hanke <hanke@dkrz.de>
 *             Rene Redler <rene.redler@mpimet.mpg.de>
 * URL: https://doc.redmine.dkrz.de/YAC/html/index.html
 *
 * This file is part of YAC.
 *
 * YAC is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * YAC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with YAC.  If not, see <http://www.gnu.org/licenses/gpl.txt>.
 */

#ifndef GRID_UNSTRUCT_H
#define GRID_UNSTRUCT_H

#include "grid.h"

struct grid * yac_unstruct_grid_new(
  double * coordinates_x, double * coordinates_y, unsigned num_vertices,
  struct dep_list * cell_to_vertex);

struct grid * yac_unpack_unstruct_grid(
  void * buffer, int buffer_size, int * position, struct communicator * comm);

void yac_unstruct_grid_set_cell_to_vertex_by_user(
  struct grid * grid, unsigned cell_to_vertex_by_user);

#endif // GRID_UNSTRUCT_H
